@@ -17,7 +17,7 @@ import copy
 import boto3
 import botocore
 from multiprocessing.pool import ThreadPool
-import shapely
+# import shapely
 
 pd.options.display.max_columns = 10
 
@@ -215,7 +215,3 @@ def process_results_output(ts_xr, parameter, modified_date=False, quality_code=F
         return json1
     else:
         raise ValueError("output must be one of 'Dataset', 'DataArray', 'Dict', or 'json'")
-
-
-
-
